# Bootstrap build
# Tycho depends on itself, and Eclipse to build but in certain cases
# these requirements may not be satisfiable.

# Set 'tycho_bootstrap' if Tycho from buildroot is broken or non-existent
# This basically uses javac + xmvn to build only the Tycho components
# required to perform a full Tycho build
# Most common usage : A library (in Fedora) used by Tycho's runtime broke API
%global tycho_bootstrap 0
# Set 'eclipse_bootstrap' if Eclipse from buildroot cannot help build Tycho
# This basically provides a location for usage of pre-bundled Eclipse
# Possible uses : Need to build Tycho before Eclipse in fresh buildroot
%global eclipse_bootstrap 0
# When building version under development (non-release)
# %%global snap -SNAPSHOT
%global snap %{nil}

%global git_tag tycho-0.25.0

%global fp_p2_sha 4e1319
%global fp_p2_version 0.0.1
%global fp_p2_snap -SNAPSHOT

%define __requires_exclude osgi*

Name:           tycho
Version:        0.25.0
Release:        %mkrel 7
Group:          Development/Java
Summary:        Plugins and extensions for building Eclipse plugins and OSGI bundles with Maven

# license file is missing but all files having some licensing information are ASL 2.0
License:        ASL 2.0 and EPL
URL:            http://eclipse.org/tycho
Source0:        http://git.eclipse.org/c/tycho/org.eclipse.tycho.git/snapshot/org.eclipse.tycho-%{git_tag}.tar.xz

# this is a workaround for maven-plugin-plugin changes that happened after
# version 2.4.3 (impossible to have empty mojo created as aggregate). This
# should be fixed upstream properly
Source1:        EmptyMojo.java
Source2:        tycho-scripts.sh
Source3:        tycho-bootstrap.sh
Source4:        tycho-debundle.sh
# Fedora Eclipse bundles needed to build Tycho when Eclipse is not present
# or when the Eclipse that is present is not compatible
%if %{eclipse_bootstrap}
Source5:        eclipse-bootstrap-neon.tar.xz
%endif
# Eclipse Plugin Project supporting filesystem as p2 repository
# https://github.com/rgrunber/fedoraproject-p2
# Generated using 'git archive --prefix=fedoraproject-p2/ -o fedoraproject-p2-%%{fp_p2_sha}.tar %%{fp_p2_sha} && xz fedoraproject-p2-%%{fp_p2_sha}.tar'
Source6:        fedoraproject-p2-%{fp_p2_sha}.tar.xz
# Script that can be used to install or simulate installation of P2
# artifacts. It is used in OSGi requires generation.
Source7:        p2-install.sh

Patch0:         %{name}-fix-build.patch
Patch2:         %{name}-fix-surefire.patch
Patch3:         %{name}-use-custom-resolver.patch
Patch4:         %{name}-maven-delegation.patch
# Additional changes needed just for bootstrap build
Patch5:         %{name}-fix-bootstrap-build.patch
# Accepted upstream: https://git.eclipse.org/r/49897
Patch7:         %{name}-port-to-plexus-archiver-3.0.1.patch
Patch8:         tycho-maven-archiver-3.0.1.patch
Patch9:         tycho-eclipse-neon.patch

BuildArch:      noarch

BuildRequires:  maven-local
BuildRequires:  xmvn
BuildRequires:  maven-clean-plugin
BuildRequires:  maven-dependency-plugin
BuildRequires:  maven-install-plugin
BuildRequires:  maven-release-plugin
BuildRequires:  maven-verifier
BuildRequires:  objectweb-asm
BuildRequires:  plexus-containers-component-metadata
BuildRequires:  apache-commons-exec
BuildRequires:  bcel
BuildRequires:  decentxml
BuildRequires:  easymock
BuildRequires:  ecj >= 1:4.5.2-2
BuildRequires:  maven-plugin-testing-harness
BuildRequires:  xmvn-parent-pom
BuildRequires:  maven-plugin-bundle
BuildRequires:  maven-plugin-plugin
BuildRequires:  maven-source-plugin
%if %{tycho_bootstrap}
BuildRequires:  maven-deploy-plugin
BuildRequires:  maven-site-plugin
%else
BuildRequires:  %{name}
%endif
%if %{eclipse_bootstrap}
# Dependencies for Eclipse bundles we use
BuildRequires:  eclipse-filesystem
BuildRequires:  apache-commons-jxpath
BuildRequires:  geronimo-annotation
BuildRequires:  glassfish-jsp-api
BuildRequires:  icu4j
BuildRequires:  sac
BuildRequires:  sat4j
BuildRequires:  xz-java
%else
BuildRequires:  eclipse-platform >= 1:4.6.0
%endif
BuildRequires:  jetty-http
BuildRequires:  jetty-util
BuildRequires:  jetty-security
BuildRequires:  jetty-server
BuildRequires:  jetty-servlet
BuildRequires:  maven-shared-utils
BuildRequires:  mockito
BuildRequires:  zip

Requires:       apache-commons-exec
Requires:       decentxml
Requires:       maven-local
Requires:       xmvn
Requires:       maven-dependency-plugin
Requires:       maven-verifier
Requires:       objectweb-asm
Requires:       ecj >= 1:4.5.2-2
Requires:       maven-plugin-testing-harness
%if ! %{eclipse_bootstrap}
Requires:       eclipse-platform >= 1:4.6.0
%endif

# Tycho always tries to resolve all build plugins, even if they are
# not needed during Maven lifecycle.  This means that Tycho will try
# to resolve plugins like clean, deploy or site, which aren't normally
# used during package build.  See rhbz#971301
Requires:       maven-clean-plugin
Requires:       maven-deploy-plugin
Requires:       maven-install-plugin
Requires:       maven-site-plugin

# Required by tycho-source-plugin, but XMvn fails to generate
# auto-requires due to uncommon dependency <type>maven-plugin</type>
Requires:       maven-source-plugin

%description
Tycho is a set of Maven plugins and extensions for building Eclipse
plugins and OSGI bundles with Maven. Eclipse plugins and OSGI bundles
have their own metadata for expressing dependencies, source folder
locations, etc. that are normally found in a Maven POM. Tycho uses
native metadata for Eclipse plugins and OSGi bundles and uses the POM
to configure and drive the build. Tycho supports bundles, fragments,
features, update site projects and RCP applications. Tycho also knows
how to run JUnit test plugins using OSGi runtime and there is also
support for sharing build results using Maven artifact repositories.

Tycho plugins introduce new packaging types and the corresponding
lifecycle bindings that allow Maven to use OSGi and Eclipse metadata
during a Maven build. OSGi rules are used to resolve project
dependencies and package visibility restrictions are honored by the
OSGi-aware JDT-based compiler plugin. Tycho will use OSGi metadata and
OSGi rules to calculate project dependencies dynamically and injects
them into the Maven project model at build time. Tycho supports all
attributes supported by the Eclipse OSGi resolver (Require-Bundle,
Import-Package, Eclipse-GenericRequire, etc). Tycho will use proper
classpath access rules during compilation. Tycho supports all project
types supported by PDE and will use PDE/JDT project metadata where
possible. One important design goal in Tycho is to make sure there is
no duplication of metadata between POM and OSGi metadata.



%package javadoc
Summary:        Javadocs for %{name}

%description javadoc
This package contains the API documentation for %{name}.

%prep
%setup -q -n org.eclipse.tycho-%{git_tag}

# Prepare fedoraproject-p2
tar -xf %{SOURCE6}

%pom_disable_module org.fedoraproject.p2.tests fedoraproject-p2

%patch0 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch7 -p0
%patch8 -p0
%patch9 -p0

find tycho-core -iname '*html' -delete

sed -i -e 's/org.apache.maven.it.util.DirectoryScanner/org.apache.maven.shared.utils.io.DirectoryScanner/g' tycho-testing-harness/src/main/java/org/eclipse/tycho/test/AbstractTychoIntegrationTest.java

# Move from org.sonatype.aether to org.eclipse.aether
find . -name "*.java" | xargs sed -i 's/org.sonatype.aether/org.eclipse.aether/g'
find . -name "*.java" | xargs sed -i 's/org.eclipse.aether.util.DefaultRepositorySystemSession/org.eclipse.aether.DefaultRepositorySystemSession/g'
sed -i 's/public int getPriority/public float getPriority/g' tycho-core/src/main/java/org/eclipse/tycho/core/p2/P2RepositoryConnectorFactory.java

# place empty mojo in place
mkdir -p tycho-maven-plugin/src/main/java/org/fedoraproject
pushd tycho-maven-plugin/src/main/java/org/fedoraproject
cp %{SOURCE1} .
popd

# These units cannot be found during a regular build
sed -i '/^<unit id=.*$/d' tycho-bundles/tycho-bundles-target/tycho-bundles-target.target

# we don't have org.apache.commons:commons-compress:jar:sources
%pom_xpath_remove "pom:dependency[pom:classifier='sources' and pom:artifactId='commons-compress']" tycho-p2/tycho-p2-director-plugin

# Previously, JUnit would re-export Hamcrest
# Now modules using org.hamcrest.core must state the requirement explicitly
for mod in tycho-bundles/org.eclipse.tycho.{p2.{maven.repository.tests,resolver.impl.test,tools.tests},test.utils,core.shared.tests}; do
  sed -i 's/^Require-Bundle://
          /org\.junit/ i Require-Bundle: org.hamcrest.core,' \
          $mod/META-INF/MANIFEST.MF
done

# Fix bundle names
sed -i -e 's/org\.hamcrest/org.hamcrest.core/' tycho-bundles/pom.xml
sed -i -e 's/org\.mockito/org.mockito.mockito-core/' \
  tycho-bundles/org.eclipse.tycho.p2.tools.tests/META-INF/MANIFEST.MF \
  tycho-bundles/org.eclipse.tycho.p2.maven.repository.tests/META-INF/MANIFEST.MF

# Bootstrap Build
%if %{eclipse_bootstrap}
# Unpack a compatible version of Eclipse we can use to build against
tar -xf %{SOURCE5}
ln -s lib64 bootstrap/usr/lib
# Install OSGi bundles into local repo to override any incompatible system version
# that may be already installed
pushd bootstrap
for f in usr/lib64/eclipse/plugins/org.eclipse.osgi.compatibility.state_*.jar \
         usr/lib64/eclipse/plugins/org.eclipse.osgi.services_*.jar \
         usr/lib64/eclipse/plugins/org.eclipse.osgi_*.jar ; do
  xmvn -o install:install-file -Dfile=$f -Dpackaging=jar -DgroupId=org.eclipse.tycho -Dmaven.repo.local=$(pwd)/../.m2 \
    -DartifactId=$(echo $(basename $f) | cut -d_ -f1) -Dversion=$(echo "${f%.jar}" | cut -d_ -f2)
done
popd
%endif

%if %{tycho_bootstrap}

%patch5 -p1

# Perform the 'minimal' (bootstrap) build of Tycho
cp %{SOURCE2} %{SOURCE3} .
./tycho-bootstrap.sh %{eclipse_bootstrap}

%patch5 -p1 -R

# Non-Bootstrap Build
%else

# Set some temporary build version so that the bootstrapped build has
# a different version from the nonbootstrapped. Otherwise there will
# be cyclic dependencies.

medadataFile=%{_datadir}/maven-metadata/tycho.xml
sysVer=`grep -C 1 "<artifactId>tycho</artifactId>" %{_mavenpomdir}/JPP.tycho-main.pom | grep "version" | sed 's/.*>\(.*\)<.*/\1/'`
mkdir boot

# Copy Tycho POMs from system repo and set their versions to %%{version}-SNAPSHOT.
for pom in $(grep 'pom</ns[0-9]:path>' $medadataFile | sed 's|.*>\(.*\)<.*|\1|'); do
    sed '
    s/$sysVer/%{version}-SNAPSHOT/g
    s/%{fp_p2_version}%{fp_p2_snap}/%{fp_p2_version}/
' <$pom >boot/$(basename $pom)
done

# Update Maven lifecycle mappings for Tycho packaging types provided by tycho-maven-plugin.
cp %{_javadir}/tycho/tycho-maven-plugin.jar boot/tycho-maven-plugin.jar
jar xf boot/tycho-maven-plugin.jar META-INF/plexus/components.xml
sed -i s/$sysVer/%{version}-SNAPSHOT/ META-INF/plexus/components.xml
jar uf boot/tycho-maven-plugin.jar META-INF/plexus/components.xml

# Create XMvn metadata for the new JARs and POMs by customizing system Tycho metadata.
sed '
  s|>/[^<]*/\([^/]*\.pom\)</\(ns[0-9]\):path>|>'$PWD'/boot/\1</\2:path>|
  s|>'$sysVer'</\(ns[0-9]\):version>|>%{version}-SNAPSHOT</\1:version><\1:compatVersions><\1:version>%{version}-SNAPSHOT</\1:version></\1:compatVersions>|
  s|>'%{fp_p2_version}%{fp_p2_snap}'</\(ns[0-9]\):version>|>%{fp_p2_version}</\1:version><\1:compatVersions><\1:version>%{fp_p2_version}</\1:version></\1:compatVersions>|
  s|%{_javadir}/tycho/tycho-maven-plugin.jar|'$PWD'/boot/tycho-maven-plugin.jar|
' $medadataFile >boot/tycho-metadata.xml
%mvn_config resolverSettings/metadataRepositories/repository $PWD/boot/tycho-metadata.xml

%endif

# Tests are skipped anyways, so remove some test dependencies
%pom_xpath_remove "pom:dependency[pom:classifier='tests']" tycho-compiler-plugin
%pom_xpath_remove "pom:dependency[pom:classifier='tests']" tycho-packaging-plugin

sed -i -e "s|javax.servlet|javax.servlet-api|g" tycho-bundles/org.eclipse.tycho.test.utils/META-INF/MANIFEST.MF

%build
xmvn -o -Dtycho-version=%{version}-SNAPSHOT -Dmaven.test.skip=true \
-Dmaven.repo.local=$(pwd)/.m2 -Dfedora.p2.repos=$(pwd)/bootstrap \
-f fedoraproject-p2/pom.xml \
clean install org.apache.maven.plugins:maven-javadoc-plugin:aggregate

xmvn -o -DtychoBootstrapVersion=%{version}-SNAPSHOT -Dmaven.test.skip=true \
-Dmaven.repo.local=$(pwd)/.m2 -Dfedora.p2.repos=$(pwd)/bootstrap \
clean install org.apache.maven.plugins:maven-javadoc-plugin:aggregate

%install
cp %{SOURCE2} %{SOURCE4} .

install -dm 755 $RPM_BUILD_ROOT%{_javadir}/tycho
install -dm 755 $RPM_BUILD_ROOT%{_mavenpomdir}

# fedoraproject-p2 parent
mod=fedoraproject-p2
install -pm 644 $mod/pom.xml $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$mod.pom
%add_maven_depmap JPP.%{name}-$mod.pom

# fedoraproject-p2
for mod in fedoraproject-p2/{org.fedoraproject.p2,xmvn-p2-installer-plugin}; do
   echo $mod
   aid=`basename $mod`
   install -pm 644 $mod/pom.xml  $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$aid.pom
   install -m 644 $mod/target/$aid-%{fp_p2_version}%{fp_p2_snap}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/$aid.jar
   %add_maven_depmap JPP.%{name}-$aid.pom %{name}/$aid.jar -a "org.eclipse.tycho:$aid"
done

# pom and jar installation
for mod in target-platform-configuration tycho-compiler-{jdt,plugin} \
           tycho-{artifactcomparator,core,embedder-api,metadata-model,testing-harness} \
           sisu-equinox/sisu-equinox{-api,-launching,-embedder} \
           tycho-p2/tycho-p2-{facade,plugin,{director,publisher,repository}-plugin} \
           tycho-{maven,packaging,pomgenerator,release/tycho-versions,source}-plugin \
           tycho-bundles/org*  \
           tycho-surefire/{tycho-surefire-plugin,org.eclipse.tycho.surefire.{osgibooter,junit,junit4{,7}}}; do
   echo $mod
   aid=`basename $mod`
   install -pm 644 $mod/pom.xml  $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$aid.pom
   install -m 644 $mod/target/$aid-%{version}%{snap}.jar $RPM_BUILD_ROOT%{_javadir}/%{name}/$aid.jar
   %add_maven_depmap JPP.%{name}-$aid.pom %{name}/$aid.jar -a "org.eclipse.tycho:$aid"
done

# pom installation
for pommod in tycho-p2 tycho-bundles tycho-surefire \
              tycho-release sisu-equinox; do
   aid=`basename $pommod`
   install -pm 644 $pommod/pom.xml \
               $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-$aid.pom
   %add_maven_depmap JPP.%{name}-$aid.pom -a "org.eclipse.tycho:$aid"
done

# p2 runtime
dir=.m2/org/eclipse/tycho/tycho-bundles-external/%{version}%{snap}
%if ! %{eclipse_bootstrap}
./%{name}-debundle.sh tycho-bundles/tycho-bundles-external/ $dir/tycho-bundles-external-%{version}*.zip $RPM_BUILD_ROOT%{_javadir}/%{name}/tycho-bundles-external-manifest.txt
%endif
install -pm 644 $dir/tycho-bundles-external-%{version}*.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-tycho-bundles-external.pom
install -m 644 $dir/tycho-bundles-external-%{version}*.zip $RPM_BUILD_ROOT%{_javadir}/%{name}/tycho-bundles-external.zip
%add_maven_depmap JPP.%{name}-tycho-bundles-external.pom %{name}/tycho-bundles-external.zip -a "org.eclipse.tycho:tycho-bundles-external"
%if ! %{eclipse_bootstrap}
%add_maven_depmap org.eclipse.tycho:tycho-bundles-external:txt:manifest:%{version}%{snap} %{name}/tycho-bundles-external-manifest.txt
%endif

# main
install -pm 644 pom.xml  $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-main.pom
%add_maven_depmap JPP.%{name}-main.pom

# standalone p2 director
%if ! %{eclipse_bootstrap}
./%{name}-debundle.sh tycho-bundles/tycho-standalone-p2-director/ .m2/org/eclipse/tycho/tycho-standalone-p2-director/%{version}%{snap}/tycho-standalone-p2-director-%{version}*.zip
%endif
pushd .m2/org/eclipse/tycho/tycho-standalone-p2-director/%{version}%{snap}/
install -m 644 tycho-standalone-p2-director-%{version}*.zip $RPM_BUILD_ROOT%{_javadir}/%{name}/tycho-standalone-p2-director.zip
install -pm 644 tycho-standalone-p2-director-%{version}*.pom $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.%{name}-tycho-standalone-p2-director.pom
popd
%add_maven_depmap JPP.%{name}-tycho-standalone-p2-director.pom tycho/tycho-standalone-p2-director.zip -a "org.eclipse.tycho:tycho-standalone-p2-director"

# javadoc
install -dm 755 $RPM_BUILD_ROOT%{_javadocdir}/tycho
cp -pr target/site/api*/* $RPM_BUILD_ROOT%{_javadocdir}/tycho

# p2-install script
install -dm 755 $RPM_BUILD_ROOT%{_javadir}-utils/
install -pm 755 %{SOURCE7} $RPM_BUILD_ROOT%{_javadir}-utils/

%if %{eclipse_bootstrap}
# org.eclipse.osgi
osgiJarPath=$(find .m2/org/eclipse/tycho/org.eclipse.osgi/*/ -name "*.jar")
osgiPomPath=$(find .m2/org/eclipse/tycho/org.eclipse.osgi/*/ -name "*.pom")

install -pm 644 $osgiPomPath $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.tycho-osgi.pom
install -m 644 -T $osgiJarPath $RPM_BUILD_ROOT%{_javadir}/tycho/osgi.jar
%add_maven_depmap JPP.tycho-osgi.pom tycho/osgi.jar -a "org.eclipse.osgi:org.eclipse.osgi"

# org.eclipse.osgi.compatibility.state
osgiStateJarPath=$(find .m2/org/eclipse/tycho/org.eclipse.osgi.compatibility.state/*/ -name "*.jar")
osgiStatePomPath=$(find .m2/org/eclipse/tycho/org.eclipse.osgi.compatibility.state/*/ -name "*.pom")

install -pm 644 $osgiStatePomPath $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.tycho-osgi.compatibility.state.pom
install -m 644 -T $osgiStateJarPath $RPM_BUILD_ROOT%{_javadir}/tycho/osgi.compatibility.state.jar
%add_maven_depmap JPP.tycho-osgi.compatibility.state.pom tycho/osgi.compatibility.state.jar -a "org.eclipse.osgi:org.eclipse.osgi.compatibility.state"

# org.eclipse.osgi.services
osgiServJarPath=$(find .m2/org/eclipse/tycho/org.eclipse.osgi.services/*/ -name "*.jar")
osgiServPomPath=$(find .m2/org/eclipse/tycho/org.eclipse.osgi.services/*/ -name "*.pom")

install -pm 644 $osgiServPomPath $RPM_BUILD_ROOT%{_mavenpomdir}/JPP.tycho-osgi.services.pom
install -m 644 -T $osgiJarPath $RPM_BUILD_ROOT%{_javadir}/tycho/osgi.services.jar
%add_maven_depmap JPP.tycho-osgi.services.pom tycho/osgi.services.jar -a "org.eclipse.osgi:org.eclipse.osgi.services"
%endif

# Symlink XMvn P2 plugin with all dependencies so that it can be loaded by XMvn
install -dm 755 %{buildroot}%{_datadir}/xmvn/lib/installer/
%if %{eclipse_bootstrap}
ln -s %{_javadir}/tycho/osgi.jar %{buildroot}%{_datadir}/xmvn/lib/installer/
%else
ln -s %{_javadir}/eclipse/osgi.jar %{buildroot}%{_datadir}/xmvn/lib/installer/
%endif
ln -s %{_javadir}/tycho/xmvn-p2-installer-plugin.jar %{buildroot}%{_datadir}/xmvn/lib/installer/
ln -s %{_javadir}/tycho/org.fedoraproject.p2.jar %{buildroot}%{_datadir}/xmvn/lib/installer/

%files -f .mfiles
%{_datadir}/xmvn/lib/installer/*
%{_javadir}-utils/p2-install.sh
%doc README.md

%files javadoc
%{_javadocdir}/tycho




%changelog
* Mon May 15 2017 neoclust <neoclust> 0.25.0-7.mga6
+ Revision: 1101832
- Sync with fc25

* Wed May 04 2016 neoclust <neoclust> 0.25.0-3.mga6
+ Revision: 1009190
- Disable bootstrap and remove sources
- Build with bootstrap disable

* Tue May 03 2016 neoclust <neoclust> 0.25.0-2.mga6
+ Revision: 1008906
- Rebuild with fixed ecj

* Mon May 02 2016 neoclust <neoclust> 0.25.0-1.mga6
+ Revision: 1008615
- Update to latest upstream release
- Full bootstrap mode due to incompatibility with Eclipse Mars

* Wed Mar 02 2016 neoclust <neoclust> 0.23.0-19.mga6
+ Revision: 983174
- Disable bootstrap
- Second rebuild of the java stack
- Rebuild tycho on bootstrap mode
- First rebuild of the java stack
- Try to build with tycho enable
- Try to bootstrap tycho
- sync package tycho with fedora

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

* Tue Dec 30 2014 pterjan <pterjan> 0.21.0-2.mga5
+ Revision: 807422
- Clean rebuild
- Sync with Fedora 21 (update to 0.21.0)

  + dmorgan <dmorgan>
    - Bootstrap build and update to 0.20

* Wed Oct 15 2014 umeabot <umeabot> 0.19.0-3.mga5
+ Revision: 741950
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

* Sun Jun 15 2014 dmorgan <dmorgan> 0.19.0-1.mga5
+ Revision: 636477
- New version

* Wed Jan 08 2014 dmorgan <dmorgan> 0.18.1-10.mga4
+ Revision: 565546
- Fix BuildRequires

* Wed Dec 25 2013 dmorgan <dmorgan> 0.18.1-9.mga4
+ Revision: 560685
- Workaround %%clean issue

* Tue Oct 22 2013 umeabot <umeabot> 0.18.1-8.mga4
+ Revision: 546273
- Mageia 4 Mass Rebuild

* Mon Oct 07 2013 dmorgan <dmorgan> 0.18.1-7.mga4
+ Revision: 492425
- Do not use XMvn internals (rhbz #1015038)

* Thu Sep 26 2013 dmorgan <dmorgan> 0.18.1-6.mga4
+ Revision: 486592
- Rebuild against bootstrap rpm
- Add workaround for rhbz#1004310
- Improve artifact resolution using XMvn Resolver. (Bug 986900)
- Skip validateConsistentTychoVersion by default. (Bug 987271)
- New version 0.18.1
- Rebuild against new maven
- Mavenized versions org.eclipse.osgi and org.eclipse.jdt.core were
  provided by Eclipse, but since it depends on Tycho at build-time,
  we cannot depend upon it at runtime. Therefore we must provide these bundles.
- New version ( bootstrap enable)
- Disable bootstrap
- Use maven script to build

* Mon Jul 08 2013 dmorgan <dmorgan> 0.16.0-21.mga4
+ Revision: 451337
- Add support for more flexible OSGi bundle paths.

* Fri Jan 18 2013 dmorgan <dmorgan> 0.16.0-20.mga3
+ Revision: 389456
- Add support for more flexible OSGi bundle paths.
- Use OSGi Requires instead of package name.
- Expand Requires to include the Eclipse platform.
- Fix upstream Bug 361204.

* Mon Jan 14 2013 umeabot <umeabot> 0.16.0-19.mga3
+ Revision: 384933
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Dec 03 2012 dmorgan <dmorgan> 0.16.0-18.mga3
+ Revision: 326021
- Fix builrequires
- New snapshot
- Add apache-commons-codec/logging as buildrequire
- Add apache-commons-httpclient as buildrequire

* Fri Sep 14 2012 dmorgan <dmorgan> 0.16.0-7.df2c35.2.mga3
+ Revision: 293950
- Try to build in non bootstrap mode
- Rebuild after first bootstrap
- New version
- new version 0.14.1
- Revert to version 0.10
- Fix Tycho Surfire to run Eclipse test bundles.
- Implement automatic creation of a system p2 repository.
- Allow building SWT fragments (BZ #380934).
- Set BREE to be at least JavaSE-1.6 for Eclipse OSGi bundles
- Implement a custom resolver when running in local mode.
- Use upstream solution for BZ #372395 to fix the build.
- Add missing tycho-testing-harness to be packaged.
- Use %%{_eclipse_base} from eclipse-platform.

* Wed Jul 20 2011 dmorgan <dmorgan> 0.10.0-2.mga2
+ Revision: 126990
- Disable bootstrap

* Tue Jul 19 2011 dmorgan <dmorgan> 0.10.0-1.mga2
+ Revision: 126755
- imported package tycho


* Fri May 6 2011 Alexander Kurtakov <akurtako@redhat.com> 0.10.0-3
- Non-bootstrap build.

* Tue May  3 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.10.0-2
- Add README and make build more silent

* Tue Mar 29 2011 Stanislav Ochotnicky <sochotnicky@redhat.com> - 0.10.0-1
- First bootstrapped version
